@@ -11,7 +11,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from torchmetrics.audio.pit import PIT  # noqa: F401
+from torchmetrics.audio.pit import PIT, PermutationInvariantTraining  # noqa: F401
+from torchmetrics.audio.sdr import SDR, ScaleInvariantSignalDistortionRatio, SignalDistortionRatio  # noqa: F401
 from torchmetrics.audio.si_sdr import SI_SDR  # noqa: F401
 from torchmetrics.audio.si_snr import SI_SNR  # noqa: F401
-from torchmetrics.audio.snr import SNR  # noqa: F401
+from torchmetrics.audio.snr import SNR, ScaleInvariantSignalNoiseRatio, SignalNoiseRatio  # noqa: F401
+from torchmetrics.utilities.imports import _PESQ_AVAILABLE, _PYSTOI_AVAILABLE
+
+if _PESQ_AVAILABLE:
+    from torchmetrics.audio.pesq import PerceptualEvaluationSpeechQuality  # noqa: F401
+
+if _PYSTOI_AVAILABLE:
+    from torchmetrics.audio.stoi import ShortTimeObjectiveIntelligibility  # noqa: F401
