@@ -14,6 +14,7 @@
 from typing import Any, Callable, Optional
 
 import torch
+from deprecate import deprecated, void
 from torch import Tensor
 
 from torchmetrics.functional.classification.matthews_corrcoef import (
@@ -21,9 +22,10 @@ from torchmetrics.functional.classification.matthews_corrcoef import (
     _matthews_corrcoef_update,
 )
 from torchmetrics.metric import Metric
+from torchmetrics.utilities import _future_warning
 
 
-class MatthewsCorrcoef(Metric):
+class MatthewsCorrCoef(Metric):
     r"""
     Calculates `Matthews correlation coefficient`_ that measures
     the general correlation or quality of a classification. In the binary case it
@@ -52,23 +54,23 @@ class MatthewsCorrcoef(Metric):
     Args:
         num_classes: Number of classes in the dataset.
         threshold:
-            Threshold value for binary or multi-label probabilites. default: 0.5
+            Threshold value for binary or multi-label probabilites.
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False. default: True
+            Forward only calls ``update()`` and return None if this is set to False.
         dist_sync_on_step:
             Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step. default: False
+            before returning the value at the step.
         process_group:
-            Specify the process group on which synchronization is called. default: None (which selects the entire world)
+            Specify the process group on which synchronization is called.
         dist_sync_fn:
             Callback that performs the allgather operation on the metric state. When ``None``, DDP
             will be used to perform the allgather
 
     Example:
-        >>> from torchmetrics import MatthewsCorrcoef
+        >>> from torchmetrics import MatthewsCorrCoef
         >>> target = torch.tensor([1, 1, 0, 0])
         >>> preds = torch.tensor([0, 1, 0, 0])
-        >>> matthews_corrcoef = MatthewsCorrcoef(num_classes=2)
+        >>> matthews_corrcoef = MatthewsCorrCoef(num_classes=2)
         >>> matthews_corrcoef(preds, target)
         tensor(0.5774)
 
@@ -110,3 +112,29 @@ class MatthewsCorrcoef(Metric):
     def compute(self) -> Tensor:
         """Computes matthews correlation coefficient."""
         return _matthews_corrcoef_compute(self.confmat)
+
+
+class MatthewsCorrcoef(MatthewsCorrCoef):
+    """Calculates `Matthews correlation coefficient`_ that measures the general correlation or quality of a
+    classification.
+
+    Example:
+        >>> matthews_corrcoef = MatthewsCorrcoef(num_classes=2)
+        >>> matthews_corrcoef(torch.tensor([0, 1, 0, 0]), torch.tensor([1, 1, 0, 0]))
+        tensor(0.5774)
+
+    .. deprecated:: v0.7
+        Renamed in favor of :class:`torchmetrics.MatthewsCorrCoef`. Will be removed in v0.8.
+    """
+
+    @deprecated(target=MatthewsCorrCoef, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
+    def __init__(
+        self,
+        num_classes: int,
+        threshold: float = 0.5,
+        compute_on_step: bool = True,
+        dist_sync_on_step: bool = False,
+        process_group: Optional[Any] = None,
+        dist_sync_fn: Callable = None,
+    ) -> None:
+        void(num_classes, threshold, compute_on_step, dist_sync_on_step, process_group, dist_sync_fn)
