@@ -120,6 +120,8 @@ class Precision(StatScores):
         tensor(0.2500)
 
     """
+    is_differentiable = False
+    higher_is_better = True
 
     def __init__(
         self,
@@ -168,10 +170,6 @@ class Precision(StatScores):
         tp, fp, _, fn = self._get_final_stats()
         return _precision_compute(tp, fp, fn, self.average, self.mdmc_reduce)
 
-    @property
-    def is_differentiable(self) -> bool:
-        return False
-
 
 class Recall(StatScores):
     r"""
@@ -273,6 +271,8 @@ class Recall(StatScores):
         tensor(0.2500)
 
     """
+    is_differentiable = False
+    higher_is_better = True
 
     def __init__(
         self,
@@ -320,7 +320,3 @@ class Recall(StatScores):
         """
         tp, fp, _, fn = self._get_final_stats()
         return _recall_compute(tp, fp, fn, self.average, self.mdmc_reduce)
-
-    @property
-    def is_differentiable(self) -> bool:
-        return False
