@@ -29,7 +29,7 @@ def retrieval_precision(preds: Tensor, target: Tensor, k: Optional[int] = None)
     Args:
         preds: estimated probabilities of each document to be relevant.
         target: ground truth about each document being relevant or not.
-        k: consider only the top k elements (default: None, which considers them all)
+        k: consider only the top k elements (default: `None`, which considers them all)
 
     Returns:
         a single-value tensor with the precision (at ``k``) of the predictions ``preds`` w.r.t. the labels ``target``.
