@@ -14,23 +14,31 @@
 import csv
 import math
 import urllib
-import warnings
 from collections import Counter, defaultdict
 from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union
+from warnings import warn
 
 import torch
+from deprecate import deprecated
 from torch import Tensor
 from torch.utils.data import DataLoader, Dataset
 
-from torchmetrics.utilities.imports import _TQDM_AVAILABLE, _TRANSFORMERS_AVAILABLE
+from torchmetrics.utilities import _future_warning
+from torchmetrics.utilities.imports import _TQDM_AVAILABLE, _TRANSFORMERS_AUTO_AVAILABLE
 
-if _TRANSFORMERS_AVAILABLE:
-    from transformers import AutoModel, AutoTokenizer
+if _TRANSFORMERS_AUTO_AVAILABLE:
+    from transformers.models.auto import AutoModel, AutoTokenizer
+else:
+    __doctest_skip__ = ["bert_score"]
 
 if _TQDM_AVAILABLE:
     import tqdm
 
 
+# Default model recommended in the original implementation.
+_DEFAULT_MODEL = "roberta-large"
+
+
 def _preprocess_text(
     text: List[str],
     tokenizer: Any,
@@ -48,9 +56,9 @@ def _preprocess_text(
             Either `AutoTokenizer` instance from `transformers` package, or a user's own tokenizer.
         max_length:
             A maximum sequence length.
-        trunction:
+        truncation:
             An indication of whether tokenized sequences should be padded only to the length of the longest sequence.
-        sort_according_to_length:
+        sort_according_length:
             An indication of whether tokenized sequences should be sorted from shortest to longest. This is appropriate
             to do for leveraging dynamic padding during embedding calculation and thereby to hasten inference.
         own_tokenizer:
@@ -86,11 +94,10 @@ def _process_attention_mask_for_special_tokens(attention_mask: Tensor) -> Tensor
     calculation for BERT score.
 
     Args:
-        attention_mask:
-            An attention mask to be returned, for example, by a `transformers` tokenizer.
+        attention_mask: An attention mask to be returned, for example, by a `transformers` tokenizer.
 
     Return:
-        A processd attention mask.
+        A processed attention mask.
     """
     # Make attention_mask zero for [CLS] token
     attention_mask[:, 0] = 0
@@ -127,13 +134,8 @@ def _output_data_collator(model_output: Tensor, attention_mask: Tensor, target_l
     model_output = torch.cat(
         [model_output, torch.zeros(zeros_shape, dtype=model_output.dtype).to(model_output.device)], dim=2
     )
-    attention_mask = torch.cat(
-        [
-            attention_mask,
-            torch.zeros(zeros_shape[0], zeros_shape[2], dtype=attention_mask.dtype).to(attention_mask.device),
-        ],
-        dim=1,
-    )
+    zeros = torch.zeros(zeros_shape[0], zeros_shape[2], dtype=attention_mask.dtype).to(attention_mask.device)
+    attention_mask = torch.cat([attention_mask, zeros], dim=1)
     return model_output, attention_mask
 
 
@@ -164,8 +166,6 @@ class TextDataset(Dataset):
                 An indication of whether calculate token inverse document frequencies to weight the model embeddings.
             tokens_idf:
                 Inverse document frequencies (these should be calculated on reference sentences).
-            own_tokenizer:
-                An indication of whether a non-default user's own tokenizer is used.
         """
         self.text = preprocess_text_fn(text, tokenizer, max_length)
         self.max_length = self.text["input_ids"].shape[1]
@@ -244,7 +244,7 @@ class TokenizedDataset(TextDataset):
             self.tokens_idf = tokens_idf if tokens_idf is not None else self._get_tokens_idf()
 
 
-def _get_progress_bar(dataloader: DataLoader, verbose: bool = False) -> Union[DataLoader, tqdm.auto.tqdm]:
+def _get_progress_bar(dataloader: DataLoader, verbose: bool = False) -> Union[DataLoader, "tqdm.auto.tqdm"]:
     """Helper function returning either the dataloader itself when `verbose = False`, or it wraps the dataloader with
     `tqdm.auto.tqdm`, when `verbose = True` to display a progress bar during the embbeddings calculation."""
     return tqdm.auto.tqdm(dataloader) if verbose else dataloader
@@ -358,28 +358,24 @@ def _get_scaled_precision_or_recall(cos_sim: Tensor, metric: str, idf_scale: Ten
 
 
 def _get_precision_recall_f1(
-    pred_embeddings: Tensor, ref_embeddings: Tensor, pred_idf_scale: Tensor, ref_idf_scale: Tensor
+    preds_embeddings: Tensor, target_embeddings: Tensor, preds_idf_scale: Tensor, target_idf_scale: Tensor
 ) -> Tuple[Tensor, Tensor, Tensor]:
     """Calculate precision, recall and F1 score over candidate and reference sentences.
 
     Args:
-        pred_embeddings:
-            Embeddings of candidate sentenecs.
-        ref_embeddings:
-            Embeddings of reference sentences.
-        pred_idf_scale:
-            An IDF scale factor for candidate sentences.
-        ref_idf_scale:
-            An IDF scale factor for reference sentences.
+        preds_embeddings: Embeddings of candidate sentenecs.
+        target_embeddings: Embeddings of reference sentences.
+        preds_idf_scale: An IDF scale factor for candidate sentences.
+        target_idf_scale: An IDF scale factor for reference sentences.
 
     Return:
         Tensors containing precision, recall and F1 score, respectively.
     """
     # Dimensions: b = batch_size, l = num_layers, p = predictions_seq_len, r = references_seq_len, d = bert_dim
-    cos_sim = torch.einsum("blpd, blrd -> blpr", pred_embeddings, ref_embeddings)
+    cos_sim = torch.einsum("blpd, blrd -> blpr", preds_embeddings, target_embeddings)
     # Final metrics shape = (batch_size * num_layers | batch_size)
-    precision = _get_scaled_precision_or_recall(cos_sim, "precision", pred_idf_scale)
-    recall = _get_scaled_precision_or_recall(cos_sim, "recall", ref_idf_scale)
+    precision = _get_scaled_precision_or_recall(cos_sim, "precision", preds_idf_scale)
+    recall = _get_scaled_precision_or_recall(cos_sim, "recall", target_idf_scale)
 
     f1_score = 2 * precision * recall / (precision + recall)
     f1_score = f1_score.masked_fill(torch.isnan(f1_score), 0.0)
@@ -388,7 +384,7 @@ def _get_precision_recall_f1(
 
 
 def _get_hash(model_name_or_path: Optional[str] = None, num_layers: Optional[int] = None, idf: bool = False) -> str:
-    """Copied from https://github.com/Tiiiger/bert_score/blob/master/bert_score/utils.py and adjusted."""
+    """Compute `BERT_score`_ (copied and adjusted)"""
     msg = f"{model_name_or_path}_L{num_layers}{'_idf' if idf else '_no-idf'}"
     return msg
 
@@ -438,7 +434,7 @@ def _load_baseline(
         baseline = _read_csv_from_url(baseline_url)
     else:
         baseline = None
-        warnings.warn("Baseline was not successfully loaded. No baseline is going to be used.")
+        warn("Baseline was not successfully loaded. No baseline is going to be used.")
 
     return baseline
 
@@ -461,9 +457,16 @@ def _rescale_metrics_with_baseline(
     return all_metrics[..., 0], all_metrics[..., 1], all_metrics[..., 2]
 
 
+@deprecated(
+    args_mapping={"predictions": "preds", "references": "target"},
+    target=True,
+    deprecated_in="0.7",
+    remove_in="0.8",
+    stream=_future_warning,
+)
 def bert_score(
-    predictions: Union[List[str], Dict[str, Tensor]],
-    references: Union[List[str], Dict[str, Tensor]],
+    preds: Union[List[str], Dict[str, Tensor]],
+    target: Union[List[str], Dict[str, Tensor]],
     model_name_or_path: Optional[str] = None,
     num_layers: Optional[int] = None,
     all_layers: bool = False,
@@ -482,22 +485,21 @@ def bert_score(
     baseline_path: Optional[str] = None,
     baseline_url: Optional[str] = None,
 ) -> Dict[str, Union[List[float], str]]:
-    """`BERTScore <https://arxiv.org/abs/1904.09675>`_ leverages the pre-trained contextual embeddings from BERT
-    and matches words in candidate and reference sentences by cosine similarity. It has been shown to correlate
-    with human judgment on sentence-level and system-level evaluation. Moreover, BERTScore computes precision,
-    recall, and F1 measure, which can be useful for evaluating different language generation tasks. assert
-    len(predictions) == len(references), "Number of predicted and reference sententes must be the same!".
+    """`Bert_score Evaluating Text Generation`_ leverages the pre-trained contextual embeddings from BERT and
+    matches words in candidate and reference sentences by cosine similarity. It has been shown to correlate with
+    human judgment on sentence-level and system-level evaluation. Moreover, BERTScore computes precision, recall,
+    and F1 measure, which can be useful for evaluating different language generation tasks.
 
-    This implemenation follows the original implementation from https://github.com/Tiiiger/bert_score.
+    This implemenation follows the original implementation from `BERT_score`_
 
     Args:
-        predictions:
+        preds:
             Either an iterable of predicted sentences or a `Dict[str, torch.Tensor]` containing `input_ids` and
             `attention_mask` `torch.Tensor`.
-        references:
+        target:
             Either an iterable of target sentences or a `Dict[str, torch.Tensor]` containing `input_ids` and
             `attention_mask` `torch.Tensor`.
-        model_type:
+        model_name_or_path:
             A name or a model path used to load `transformers` pretrained model.
         num_layers:
             A layer of representation to use.
@@ -536,9 +538,9 @@ def bert_score(
         rescale_with_baseline:
             An indication of whether bertscore should be rescaled with a pre-computed baseline.
             When a pretrained model from `transformers` model is used, the corresponding baseline is downloaded
-            from the original `bert-score` package from https://github.com/Tiiiger/bert_score if available.
+            from the original `bert-score` package from `BERT_score`_ if available.
             In other cases, please specify a path to the baseline csv/tsv file, which must follow the formatting
-            of the files from https://github.com/Tiiiger/bert_score.
+            of the files from `BERT_score`_
         baseline_path:
             A path to the user's own local csv/tsv file with the baseline scale.
         baseline_url:
@@ -547,42 +549,57 @@ def bert_score(
     Returns:
         Python dictionary containing the keys `precision`, `recall` and `f1` with corresponding values.
 
+    .. deprecated:: v0.7
+        Args:
+            predictions:
+                This argument is deprecated in favor of  `preds` and will be removed in v0.8.
+            references:
+                This argument is deprecated in favor of  `target` and will be removed in v0.8.
+
     Raises:
         ValueError:
-            If `len(predictions) != len(references)`.
-        ValueError:
+            If `len(preds) != len(target)`.
+        ModuleNotFoundError:
             If `tqdm` package is required and not installed.
+        ModuleNotFoundError:
+            If ``transformers`` package is required and not installed.
         ValueError:
-            If `transformers` package is required and not installed.
-        ValueError:
-            If `num_layer` is larger than the number of the model layers.
+            If ``num_layer`` is larger than the number of the model layers.
         ValueError:
             If invalid input is provided.
 
     Example:
-        >>> predictions = ["hello there", "general kenobi"]
-        >>> references = ["hello there", "master kenobi"]
-        >>> bert_score(predictions=predictions, references=references, lang="en")  # doctest: +SKIP
-        {'precision': [0.99..., 0.99...],
-         'recall': [0.99..., 0.99...],
-         'f1': [0.99..., 0.99...]}
+        >>> from torchmetrics.functional.text.bert import bert_score
+        >>> preds = ["hello there", "general kenobi"]
+        >>> target = ["hello there", "master kenobi"]
+        >>> from pprint import pprint
+        >>> pprint(bert_score(preds, target)) # doctest: +ELLIPSIS
+        {'f1': [0.999..., 0.996...],
+         'precision': [0.999..., 0.996...],
+         'recall': [0.999..., 0.996...]}
     """
-    if len(predictions) != len(references):
+    if len(preds) != len(target):
         raise ValueError("Number of predicted and reference sententes must be the same!")
 
     if verbose and (not _TQDM_AVAILABLE):
-        raise ValueError(
+        raise ModuleNotFoundError(
             "An argument `verbose = True` requires `tqdm` package be installed. Install with `pip install tqdm`."
         )
 
     if model is None:
-        if not _TRANSFORMERS_AVAILABLE:
-            raise ValueError(
-                "`bert_score` metric with default models requires `transformers` package be installed. "
-                "Either install with `pip install transformers>=4.0` or `pip install torchmetrics[text]`"
+        if not _TRANSFORMERS_AUTO_AVAILABLE:
+            raise ModuleNotFoundError(
+                "`bert_score` metric with default models requires `transformers` package be installed."
+                " Either install with `pip install transformers>=4.0` or `pip install torchmetrics[text]`."
             )
-        tokenizer = AutoTokenizer.from_pretrained(model_name_or_path)
-        model = AutoModel.from_pretrained(model_name_or_path)
+        if model_name_or_path is None:
+            warn(
+                "The argument `model_name_or_path` was not specified while it is required when default"
+                " `transformers` model are used."
+                f"It is, therefore, used the default recommended model - {_DEFAULT_MODEL}."
+            )
+        tokenizer = AutoTokenizer.from_pretrained(model_name_or_path or _DEFAULT_MODEL)
+        model = AutoModel.from_pretrained(model_name_or_path or _DEFAULT_MODEL)
     else:
         tokenizer = user_tokenizer
     model.eval()
@@ -595,17 +612,17 @@ def bert_score(
                 f"Please use num_layers <= {model.config.num_hidden_layers}"  # type: ignore
             )
     except AttributeError:
-        warnings.warn("It was not possible to retrieve the parameter `num_layers` from the model specification.")
+        warn("It was not possible to retrieve the parameter `num_layers` from the model specification.")
 
-    _are_empty_lists = all(isinstance(text, list) and len(text) == 0 for text in (predictions, references))
+    _are_empty_lists = all(isinstance(text, list) and len(text) == 0 for text in (preds, target))
     _are_valid_lists = all(
-        isinstance(text, list) and len(text) > 0 and isinstance(text[0], str) for text in (predictions, references)
+        isinstance(text, list) and len(text) > 0 and isinstance(text[0], str) for text in (preds, target)
     )
     _are_valid_tensors = all(
-        isinstance(text, dict) and isinstance(text["input_ids"], Tensor) for text in (predictions, references)
+        isinstance(text, dict) and isinstance(text["input_ids"], Tensor) for text in (preds, target)
     )
     if _are_empty_lists:
-        warnings.warn("Predictions and references are empty.")
+        warn("Predictions and references are empty.")
         output_dict: Dict[str, Union[List[float], str]] = {
             "precision": [0.0],
             "recall": [0.0],
@@ -620,32 +637,32 @@ def bert_score(
 
     # We ignore mypy typing below as the proper typing is ensured by conditions above, only mypy cannot infer that.
     if _are_valid_lists:
-        ref_dataset = TextDataset(references, tokenizer, max_length, idf=idf)  # type: ignore
-        pred_dataset = TextDataset(
-            predictions,  # type: ignore
+        target_dataset = TextDataset(target, tokenizer, max_length, idf=idf)  # type: ignore
+        preds_dataset = TextDataset(
+            preds,  # type: ignore
             tokenizer,
             max_length,
             idf=idf,
-            tokens_idf=ref_dataset.tokens_idf,
+            tokens_idf=target_dataset.tokens_idf,
         )
     elif _are_valid_tensors:
-        ref_dataset = TokenizedDataset(**references, idf=idf)  # type: ignore
-        pred_dataset = TokenizedDataset(**predictions, idf=idf, tokens_idf=ref_dataset.tokens_idf)  # type: ignore
+        target_dataset = TokenizedDataset(**target, idf=idf)  # type: ignore
+        preds_dataset = TokenizedDataset(**preds, idf=idf, tokens_idf=target_dataset.tokens_idf)  # type: ignore
     else:
         raise ValueError("Invalid input provided.")
 
-    ref_loader = DataLoader(ref_dataset, batch_size=batch_size, num_workers=num_threads)
-    pred_loader = DataLoader(pred_dataset, batch_size=batch_size, num_workers=num_threads)
+    target_loader = DataLoader(target_dataset, batch_size=batch_size, num_workers=num_threads)
+    preds_loader = DataLoader(preds_dataset, batch_size=batch_size, num_workers=num_threads)
 
-    ref_embeddings, ref_idf_scale = _get_embeddings_and_idf_scale(
-        ref_loader, ref_dataset.max_length, model, device, num_layers, all_layers, idf, verbose, user_forward_fn
+    target_embeddings, target_idf_scale = _get_embeddings_and_idf_scale(
+        target_loader, target_dataset.max_length, model, device, num_layers, all_layers, idf, verbose, user_forward_fn
     )
-    pred_embeddings, pred_idf_scale = _get_embeddings_and_idf_scale(
-        pred_loader, pred_dataset.max_length, model, device, num_layers, all_layers, idf, verbose, user_forward_fn
+    preds_embeddings, preds_idf_scale = _get_embeddings_and_idf_scale(
+        preds_loader, preds_dataset.max_length, model, device, num_layers, all_layers, idf, verbose, user_forward_fn
     )
 
     precision, recall, f1_score = _get_precision_recall_f1(
-        pred_embeddings, ref_embeddings, pred_idf_scale, ref_idf_scale
+        preds_embeddings, target_embeddings, preds_idf_scale, target_idf_scale
     )
 
     if baseline is not None:
