@@ -14,15 +14,18 @@
 from typing import Any, Callable, List, Optional, Tuple, Union
 
 import torch
+from deprecate import deprecated, void
 from torch import Tensor
 from torch.nn import Module
 
 from torchmetrics.image.fid import NoTrainInceptionV3
 from torchmetrics.metric import Metric
-from torchmetrics.utilities import rank_zero_warn
+from torchmetrics.utilities import _future_warning, rank_zero_warn
 from torchmetrics.utilities.data import dim_zero_cat
 from torchmetrics.utilities.imports import _TORCH_FIDELITY_AVAILABLE
 
+__doctest_requires__ = {("KernelInceptionDistance", "KID"): ["torch_fidelity"]}
+
 
 def maximum_mean_discrepancy(k_xx: Tensor, k_xy: Tensor, k_yy: Tensor) -> Tensor:
     """Adapted from `KID Score`_"""
@@ -62,7 +65,7 @@ def poly_mmd(
     return maximum_mean_discrepancy(k_11, k_12, k_22)
 
 
-class KID(Metric):
+class KernelInceptionDistance(Metric):
     r"""
     Calculates Kernel Inception Distance (KID) which is used to access the quality of generated images. Given by
 
@@ -150,16 +153,16 @@ class KID(Metric):
     Example:
         >>> import torch
         >>> _ = torch.manual_seed(123)
-        >>> from torchmetrics import KID
-        >>> kid = KID(subset_size=50)  # doctest: +SKIP
+        >>> from torchmetrics.image.kid import KernelInceptionDistance
+        >>> kid = KernelInceptionDistance(subset_size=50)
         >>> # generate two slightly overlapping image intensity distributions
-        >>> imgs_dist1 = torch.randint(0, 200, (100, 3, 299, 299), dtype=torch.uint8)  # doctest: +SKIP
-        >>> imgs_dist2 = torch.randint(100, 255, (100, 3, 299, 299), dtype=torch.uint8)  # doctest: +SKIP
-        >>> kid.update(imgs_dist1, real=True)  # doctest: +SKIP
-        >>> kid.update(imgs_dist2, real=False)  # doctest: +SKIP
-        >>> kid_mean, kid_std = kid.compute()  # doctest: +SKIP
-        >>> print((kid_mean, kid_std))  # doctest: +SKIP
-        (tensor(0.0338), tensor(0.0025))
+        >>> imgs_dist1 = torch.randint(0, 200, (100, 3, 299, 299), dtype=torch.uint8)
+        >>> imgs_dist2 = torch.randint(100, 255, (100, 3, 299, 299), dtype=torch.uint8)
+        >>> kid.update(imgs_dist1, real=True)
+        >>> kid.update(imgs_dist2, real=False)
+        >>> kid_mean, kid_std = kid.compute()
+        >>> print((kid_mean, kid_std))
+        (tensor(0.0337), tensor(0.0023))
 
     """
     real_features: List[Tensor]
@@ -187,17 +190,16 @@ class KID(Metric):
         )
 
         rank_zero_warn(
-            "Metric `KID` will save all extracted features in buffer."
+            "Metric `Kernel Inception Distance` will save all extracted features in buffer."
             " For large datasets this may lead to large memory footprint.",
             UserWarning,
         )
 
         if isinstance(feature, (str, int)):
             if not _TORCH_FIDELITY_AVAILABLE:
-                raise RuntimeError(
-                    "KID metric requires that Torch-fidelity is installed."
-                    " Either install as `pip install torchmetrics[image]`"
-                    " or `pip install torch-fidelity`"
+                raise ModuleNotFoundError(
+                    "Kernel Inception Distance metric requires that `Torch-fidelity` is installed."
+                    " Either install as `pip install torchmetrics[image]` or `pip install torch-fidelity`."
                 )
             valid_int_input = ("logits_unbiased", 64, 192, 768, 2048)
             if feature not in valid_int_input:
@@ -276,3 +278,53 @@ class KID(Metric):
             kid_scores_.append(o)
         kid_scores = torch.stack(kid_scores_)
         return kid_scores.mean(), kid_scores.std(unbiased=False)
+
+
+class KID(KernelInceptionDistance):
+    r"""
+    Calculates Kernel Inception Distance (KID) which is used to access the quality of generated images.
+
+    .. deprecated:: v0.7
+        Use :class:`torchmetrics.image.KernelInceptionDistance`. Will be removed in v0.8.
+
+    Example:
+        >>> import torch
+        >>> _ = torch.manual_seed(123)
+        >>> kid = KID(subset_size=50)
+        >>> # generate two slightly overlapping image intensity distributions
+        >>> imgs_dist1 = torch.randint(0, 200, (100, 3, 299, 299), dtype=torch.uint8)
+        >>> imgs_dist2 = torch.randint(100, 255, (100, 3, 299, 299), dtype=torch.uint8)
+        >>> kid.update(imgs_dist1, real=True)
+        >>> kid.update(imgs_dist2, real=False)
+        >>> kid_mean, kid_std = kid.compute()
+        >>> print((kid_mean, kid_std))
+        (tensor(0.0337), tensor(0.0023))
+
+    """
+
+    @deprecated(target=KernelInceptionDistance, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
+    def __init__(
+        self,
+        feature: Union[str, int, torch.nn.Module] = 2048,
+        subsets: int = 100,
+        subset_size: int = 1000,
+        degree: int = 3,
+        gamma: Optional[float] = None,  # type: ignore
+        coef: float = 1.0,
+        compute_on_step: bool = False,
+        dist_sync_on_step: bool = False,
+        process_group: Optional[Any] = None,
+        dist_sync_fn: Callable = None,
+    ) -> None:
+        void(
+            feature,
+            subsets,
+            subset_size,
+            degree,
+            gamma,
+            coef,
+            compute_on_step,
+            dist_sync_on_step,
+            process_group,
+            dist_sync_fn,
+        )
