@@ -23,7 +23,7 @@ from torchmetrics.utilities.data import dim_zero_cat
 
 class CosineSimilarity(Metric):
     r"""
-    Computes the `Cosine Similarity <https://en.wikipedia.org/wiki/Cosine_similarity>`_
+    Computes the `Cosine Similarity`_
     between targets and predictions:
 
     .. math::
@@ -38,7 +38,7 @@ class CosineSimilarity(Metric):
     - ``target`` (float tensor): ``(N,d)``
 
     Args:
-        reduction : how to reduce over the batch dimension using 'sum', 'mean' or 'none'
+        reduction: how to reduce over the batch dimension using 'sum', 'mean' or 'none'
                     (taking the individual scores)
         compute_on_step:
             Forward only calls ``update()`` and return ``None`` if this is set to ``False``.
@@ -59,13 +59,16 @@ class CosineSimilarity(Metric):
         >>> cosine_similarity = CosineSimilarity(reduction = 'mean')
         >>> cosine_similarity(preds, target)
         tensor(0.8536)
+
     """
+    is_differentiable = True
+    higher_is_better = True
     preds: List[Tensor]
     target: List[Tensor]
 
     def __init__(
         self,
-        reduction: str = 'sum',
+        reduction: str = "sum",
         compute_on_step: bool = True,
         dist_sync_on_step: bool = False,
         process_group: Optional[Any] = None,
@@ -75,21 +78,22 @@ class CosineSimilarity(Metric):
             compute_on_step=compute_on_step,
             dist_sync_on_step=dist_sync_on_step,
             process_group=process_group,
-            dist_sync_fn=dist_sync_fn
+            dist_sync_fn=dist_sync_fn,
         )
+        allowed_reduction = ("sum", "mean", "none", None)
+        if reduction not in allowed_reduction:
+            raise ValueError(f"Expected argument `reduction` to be one of {allowed_reduction} but got {reduction}")
+        self.reduction = reduction
 
         self.add_state("preds", [], dist_reduce_fx="cat")
         self.add_state("target", [], dist_reduce_fx="cat")
-        self.reduction = reduction
 
     def update(self, preds: Tensor, target: Tensor) -> None:  # type: ignore
-        """
-        Update metric states with predictions and targets.
+        """Update metric states with predictions and targets.
 
         Args:
             preds: Predicted tensor with shape ``(N,d)``
             target: Ground truth tensor with shape ``(N,d)``
-
         """
         preds, target = _cosine_similarity_update(preds, target)
 
@@ -100,7 +104,3 @@ class CosineSimilarity(Metric):
         preds = dim_zero_cat(self.preds)
         target = dim_zero_cat(self.target)
         return _cosine_similarity_compute(preds, target, self.reduction)
-
-    @property
-    def is_differentiable(self) -> bool:
-        return True
