@@ -17,12 +17,15 @@
 # Date: 2020-07-18
 # Link: https://pytorch.org/text/_modules/torchtext/data/metrics.html#bleu_score
 from typing import Any, Callable, Optional, Sequence
+from warnings import warn
 
 import torch
+from deprecate import deprecated
 from torch import Tensor, tensor
 
 from torchmetrics import Metric
-from torchmetrics.functional.text.bleu import _bleu_score_compute, _bleu_score_update
+from torchmetrics.functional.text.bleu import _bleu_score_compute, _bleu_score_update, _tokenize_fn
+from torchmetrics.utilities import _future_warning
 
 
 class BLEUScore(Metric):
@@ -34,21 +37,22 @@ class BLEUScore(Metric):
         smooth:
             Whether or not to apply smoothing – see [2]
         compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False. default: True
+            Forward only calls ``update()`` and returns None if this is set to False.
         dist_sync_on_step:
             Synchronize metric state across processes at each ``forward()``
             before returning the value at the step.
         process_group:
-            Specify the process group on which synchronization is called. default: None (which selects the entire world)
+            Specify the process group on which synchronization is called.
         dist_sync_fn:
             Callback that performs the allgather operation on the metric state. When `None`, DDP
             will be used to perform the allgather.
 
     Example:
-        >>> translate_corpus = ['the cat is on the mat'.split()]
-        >>> reference_corpus = [['there is a cat on the mat'.split(), 'a cat is on the mat'.split()]]
+        >>> from torchmetrics import BLEUScore
+        >>> preds = ['the cat is on the mat']
+        >>> target = [['there is a cat on the mat', 'a cat is on the mat']]
         >>> metric = BLEUScore()
-        >>> metric(reference_corpus, translate_corpus)
+        >>> metric(preds, target)
         tensor(0.7598)
 
     References:
@@ -61,8 +65,8 @@ class BLEUScore(Metric):
 
     is_differentiable = False
     higher_is_better = True
-    trans_len: Tensor
-    ref_len: Tensor
+    preds_len: Tensor
+    target_len: Tensor
     numerator: Tensor
     denominator: Tensor
 
@@ -81,32 +85,48 @@ class BLEUScore(Metric):
             process_group=process_group,
             dist_sync_fn=dist_sync_fn,
         )
-
+        warn(
+            "Input order of targets and preds were changed to predictions firsts and targets second in v0.7."
+            " Warning will be removed in v0.8."
+        )
         self.n_gram = n_gram
         self.smooth = smooth
 
-        self.add_state("trans_len", tensor(0, dtype=torch.float), dist_reduce_fx="sum")
-        self.add_state("ref_len", tensor(0, dtype=torch.float), dist_reduce_fx="sum")
+        self.add_state("preds_len", tensor(0.0), dist_reduce_fx="sum")
+        self.add_state("target_len", tensor(0.0), dist_reduce_fx="sum")
         self.add_state("numerator", torch.zeros(self.n_gram), dist_reduce_fx="sum")
         self.add_state("denominator", torch.zeros(self.n_gram), dist_reduce_fx="sum")
 
-    def update(  # type: ignore
-        self, reference_corpus: Sequence[Sequence[Sequence[str]]], translate_corpus: Sequence[Sequence[str]]
-    ) -> None:
+    @deprecated(
+        args_mapping={"translate_corpus": "preds", "reference_corpus": "target"},
+        target=True,
+        deprecated_in="0.7",
+        remove_in="0.8",
+        stream=_future_warning,
+    )
+    def update(self, preds: Sequence[str], target: Sequence[Sequence[str]]) -> None:  # type: ignore
         """Compute Precision Scores.
 
         Args:
-            reference_corpus: An iterable of iterables of reference corpus
-            translate_corpus: An iterable of machine translated corpus
+            preds: An iterable of machine translated corpus
+            target: An iterable of iterables of reference corpus
+
+        .. deprecated:: v0.7
+            Args:
+                translate_corpus:
+                    This argument is deprecated in favor of  `preds` and will be removed in v0.8.
+                reference_corpus:
+                    This argument is deprecated in favor of  `target` and will be removed in v0.8.
         """
-        self.trans_len, self.ref_len = _bleu_score_update(
-            reference_corpus,
-            translate_corpus,
+        self.preds_len, self.target_len = _bleu_score_update(
+            preds,
+            target,
             self.numerator,
             self.denominator,
-            self.trans_len,
-            self.ref_len,
+            self.preds_len,
+            self.target_len,
             self.n_gram,
+            _tokenize_fn,
         )
 
     def compute(self) -> Tensor:
@@ -116,5 +136,5 @@ class BLEUScore(Metric):
             Tensor with BLEU Score
         """
         return _bleu_score_compute(
-            self.trans_len, self.ref_len, self.numerator, self.denominator, self.n_gram, self.smooth
+            self.preds_len, self.target_len, self.numerator, self.denominator, self.n_gram, self.smooth
         )
