@@ -14,6 +14,4 @@
 
 
 class TorchMetricsUserError(Exception):
-    """
-    Error used to inform users of a wrong combinison of Metric API calls.
-    """
+    """Error used to inform users of a wrong combinison of Metric API calls."""
